@@ -1,10 +1,11 @@
 #ifndef PYTHONQTWRAPPERSINK_H
 #define PYTHONQTWRAPPERSINK_H
+#include <Python.h>
 
 #include <QObject>
 #include <mbarcode-qt/plugininterfaces.h>
 #include <mbarcode-qt/pluginaction.h>
-#include <PythonQt.h>
+
 
 class PythonQTWrapperPlugin;
 
@@ -12,7 +13,7 @@ class PythonQTWrapperSink : public QObject, public PluginAction
 {
     Q_OBJECT
 public:
-    PythonQTWrapperSink(const PluginInterface *interface, QString sinkName, QString sinkText, QImage image, PythonQtObjectPtr PythonPluginContext);
+    PythonQTWrapperSink(const PluginInterface *interface, PyObject* sinkInstance);
     QString getName();
     QString getText();
     QImage getImage();
@@ -23,14 +24,8 @@ private:
     QString sinkBarcodeType;
     QString sinkBarcodeData;
 
-    QStringList soughtBarcodeTypes;
-    QString barcodeContentRegex;
-    QString myname; // to return from getName()
-    QString mytext; // to return from getText()
-    PythonQtObjectPtr PythonPluginContext;
-    QImage image;
+    PyObject* sinkInstance;
 
-    bool ready;
 private slots:
     void barcodeAnalysed(QString barcodeType, QString barcodeData);
 };
